@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-'''
+"""
 This module implements various transmuter classes.
 Transmuters are essentially classes that generate TransformedStructures from
 various data sources. They enable the high-throughput generation of new
@@ -8,7 +8,7 @@ structures and input files.
 
 It also includes the helper function, batch_write_vasp_input to generate an
 entire directory of vasp input files for running.
-'''
+"""
 
 from __future__ import division
 
@@ -21,7 +21,6 @@ __date__ = "Mar 4, 2012"
 
 import os
 import re
-import collections
 
 from pymatgen.alchemy.materials import TransformedStructure
 
@@ -141,6 +140,14 @@ class StandardTransmuter(object):
         for t in transformations:
             self.append_transformation(t)
 
+    def apply_filter(self, structure_filter):
+        """
+        Applies a structure_filter to the list of TransformedStructures
+        in the transmuter
+        """
+        self.transformed_structures = filter(structure_filter.test,
+                                             self.transformed_structures)
+
     def write_vasp_input(self, vasp_input_set, output_dir,
                          create_directory=True, subfolder=None,
                          include_cif=False):
@@ -159,7 +166,7 @@ class StandardTransmuter(object):
             subfolder:
                 function to create subdirectory name from
                 transformed_structure. e.g.,
-                lambda x: x.other_parameters['tags'][0] to use the first tag.
+                lambda x: x.other_parameters["tags"][0] to use the first tag.
             include_cif:
                 Boolean indication whether to output a CIF as well. CIF files
                 are generally better supported in visualization programs.
@@ -169,9 +176,30 @@ class StandardTransmuter(object):
                                include_cif)
 
     def set_parameter(self, key, value):
+        """
+        Add parameters to the transmuter. Additional parameters are stored in
+        the to_dict output.
+
+        Args:
+            key:
+                The key for the parameter.
+            value:
+                The value for the parameter.
+        """
         for x in self.transformed_structures:
             x.set_parameter(key, value)
 
+    def add_tags(self, tags):
+        """
+        Add tags for the structures generated by the transmuter.
+
+        Args:
+            tags:
+                A sequence of tags. Note that this should be a sequence of
+                strings, e.g., ["My awesome structures", "Project X"].
+        """
+        self.set_parameter("tags", tags)
+
     def __str__(self):
         output = ["Current structures"]
         output.append("------------")
@@ -180,15 +208,15 @@ class StandardTransmuter(object):
         return "\n".join(output)
 
     def append_transformed_structures(self, tstructs_or_transmuter):
-        '''
+        """
         Method is overloaded to accept either a list of transformed structures
-        or transmuter, it which case it appends the second transmuter's
+        or transmuter, it which case it appends the second transmuter"s
         structures.
 
         Args:
             tstructs_or_transmuter:
                 A list of transformed structures or a transmuter.
-        '''
+        """
         if isinstance(tstructs_or_transmuter, self.__class__):
             self.transformed_structures.extend(tstructs_or_transmuter
                                                .transformed_structures)
@@ -202,7 +230,7 @@ class CifTransmuter(StandardTransmuter):
 
     def __init__(self, cif_string, transformations=[], primitive=True,
                   extend_collection=False):
-        '''
+        """
         Generates a Transmuter from a cif string, possibly
         containing multiple structures.
 
@@ -216,7 +244,7 @@ class CifTransmuter(StandardTransmuter):
             extend_collection:
                 Whether to use more than one output structure from one-to-many
                 transformations.
-        '''
+        """
         transformed_structures = []
         lines = cif_string.split("\n")
         structure_data = []
@@ -237,7 +265,7 @@ class CifTransmuter(StandardTransmuter):
     @staticmethod
     def from_filenames(filenames, transformations=[], primitive=True,
                   extend_collection=False):
-        '''
+        """
         Generates a TransformedStructureCollection from a cif, possibly
         containing multiple structures.
 
@@ -251,7 +279,7 @@ class CifTransmuter(StandardTransmuter):
             extend_collection:
                 Whether to use more than one output structure from one-to-many
                 transformations.
-        '''
+        """
 
         allcifs = []
         for fname in filenames:
@@ -274,8 +302,6 @@ class PoscarTransmuter(StandardTransmuter):
                 List of POSCAR strings
             transformations:
                 New transformations to be applied to all structures.
-            primitive:
-                Whether to generate the primitive cell from the cif.
             extend_collection:
                 Whether to use more than one output structure from one-to-many
                 transformations.
@@ -288,12 +314,25 @@ class PoscarTransmuter(StandardTransmuter):
     @staticmethod
     def from_filenames(poscar_filenames, transformations=[],
                        extend_collection=False):
-        transformed_structures = []
+        """
+        Convenient constructor to generates a POSCAR transmuter from a list of
+        POSCAR filenames.
+
+        Args:
+            poscar_filenames:
+                List of POSCAR filenames
+            transformations:
+                New transformations to be applied to all structures.
+            extend_collection:
+                Whether to use more than one output structure from one-to-many
+                transformations.
+        """
+        tstructs = []
         for filename in poscar_filenames:
             with open(filename, "r") as f:
-                tstruct = TransformedStructure.from_poscar_string(f.read(), [])
-                transformed_structures.append(tstruct)
-        return StandardTransmuter(transformed_structures, transformations,
+                tstructs.append(TransformedStructure
+                                .from_poscar_string(f.read(), []))
+        return StandardTransmuter(tstructs, transformations,
                                   extend_collection=extend_collection)
 
 
@@ -316,24 +355,25 @@ def batch_write_vasp_input(transformed_structures, vasp_input_set, output_dir,
             Create the directory if not present. Defaults to True.
         subfolder:
             function to create subdirectory name from transformed_structure.
-            eg. lambda x: x.other_parameters['tags'][0] to use the first tag.
+            eg. lambda x: x.other_parameters["tags"][0] to use the first tag.
         include_cif:
             Boolean indication whether to output a CIF as well. CIF files are
             generally better supported in visualization programs.
     """
-    dnames_count = collections.defaultdict(int)
+    #dnames_count = collections.defaultdict(int)
+    count = 0
     for s in transformed_structures:
         formula = re.sub("\s+", "", s.final_structure.formula)
         if subfolder is not None:
             subdir = subfolder(s)
-            dirname = os.path.join(output_dir, subdir, '{}_{}'.format(formula,
-                                           dnames_count[subdir + formula] + 1))
+            dirname = os.path.join(output_dir, subdir,
+                                   "{}_{}".format(formula, count))
         else:
-            dirname = os.path.join(output_dir, '{}_{}'.format(formula,
-                                                    dnames_count[formula] + 1))
+            dirname = os.path.join(output_dir,
+                                   "{}_{}".format(formula, count))
         s.write_vasp_input(vasp_input_set, dirname, create_directory=True)
         if include_cif:
             from pymatgen.io.cifio import CifWriter
             writer = CifWriter(s.final_structure)
             writer.write_file(os.path.join(dirname, "{}.cif".format(formula)))
-        dnames_count[formula] += 1
+        count += 1
